@@ -58,19 +58,19 @@ app = web.application(
     },
 )
 
-code_dir = pathlib.Path.home() / "code"
+code_dir = pathlib.Path("code")
 meta_dir = code_dir / "meta"
-working_dir = code_dir / "working"
+# XXX working_dir = code_dir / "working"
 
 
-def update_system():
-    print(
-        subprocess.run(
-            ["poetry", "update"],
-            cwd=working_dir / "ragt.ag",
-            capture_output=True,
-        )
-    )
+# XXX def update_system():
+# XXX     print(
+# XXX         subprocess.run(
+# XXX             ["poetry", "update"],
+# XXX             cwd=working_dir / "ragt.ag",
+# XXX             capture_output=True,
+# XXX         )
+# XXX     )
 
 
 def run_ci(project):
@@ -86,28 +86,21 @@ def run_ci(project):
     gmpg.clone_repo(project_dir / "source.git", testing_dir)
     time.sleep(5)
     gmpg.strip_local_dev_deps(testing_dir)
-    print(
-        subprocess.run(
-            ["/srv/poetry/bin/poetry", "install"],
+
+    def run_poetry(*command, capture_output=False):
+        return subprocess.run(
+            ["/home/admin/.local/bin/poetry", *command],
             cwd=testing_dir,
-            capture_output=True,
+            capture_output=capture_output,
         )
-    )
+
+    print(run_poetry("install"))
     print("installation complete")
-    # XXX
-    print(
-        subprocess.run(
-            ["/srv/poetry/bin/poetry", "run", "which", "gmpg"], cwd=testing_dir
-        )
-    )
-    # XXX
-    subprocess.run(["/srv/poetry/bin/poetry", "run", "gmpg", "test"], cwd=testing_dir)
+    run_poetry("run", "gmpg", "test")
     print("testing complete")
-    subprocess.run(
-        ["/srv/poetry/bin/poetry", "run", "gmpg", "analyze"], cwd=testing_dir
-    )
+    run_poetry("run", "gmpg", "analyze")
     print("API analysis complete")
-    subprocess.run(["/srv/poetry/bin/poetry", "run", "gmpg", "graph"], cwd=testing_dir)
+    run_poetry("run", "gmpg", "graph")
     print("dependency visualization complete")
 
 
@@ -147,10 +140,10 @@ def search(db, query):
     return files
 
 
-@app.wrap
-def set_working_dir(handler, main_app):
-    web.tx.host.working_dir = working_dir
-    yield
+# XXX @app.wrap
+# XXX def set_working_dir(handler, main_app):
+# XXX     web.tx.host.working_dir = working_dir
+# XXX     yield
 
 
 @app.query
@@ -170,7 +163,7 @@ def create_project(db, name):
                 (
                     "#!/bin/sh",
                     "git -C $PWD/../working --git-dir=.git pull --rebase",
-                    f"wget --method=post -q {web.tx.origin}/code/projects/{name}",
+                    f"wget --method=post -qO- {web.tx.origin}/code/projects/{name}",
                 )
             )
         )
@@ -183,8 +176,18 @@ def create_project(db, name):
             "/code", "webint_code", "git_owner"
         )
         subprocess.run(["htpasswd", "-cb", meta_dir / "gitpasswd", "owner", token])
-    gmpg.clone_repo(
-        f"{web.tx.origin}/code/projects/{name}.git", f"{working_dir}/{name}"
+    # XXX subprocess.run(["sudo", "service", "nginx", "restart"])
+
+    # XXX gmpg.clone_repo(
+    # XXX     f"{web.tx.origin}/code/projects/{name}.git", f"{working_dir}/{name}"
+    # XXX )
+
+    web.application("webint_posts").model.create(
+        "entry",
+        url=f"/code/projects/{name}",
+        content=(
+            f"Created repository <a href=/code/projects/{name}><code>{name}</code></a>"
+        ),
     )
 
 
@@ -615,20 +618,20 @@ class Search:
         return app.view.search.results(query, app.model.search(query))
 
 
-@app.control("system")
-class System:
-    """System code."""
-
-    def get(self):
-        """"""
-        return app.view.system(web.tx.app)
-
-
-@app.control("system/update")
-class SystemUpdate:
-    """Update the system."""
-
-    def post(self):
-        """"""
-        web.enqueue(update_system)
-        return "update has been started"
+# XXX @app.control("system")
+# XXX class System:
+# XXX     """System code."""
+# XXX
+# XXX     def get(self):
+# XXX         """"""
+# XXX         return app.view.system(web.tx.app)
+# XXX
+# XXX
+# XXX @app.control("system/update")
+# XXX class SystemUpdate:
+# XXX     """Update the system."""
+# XXX
+# XXX     def post(self):
+# XXX         """"""
+# XXX         web.enqueue(update_system)
+# XXX         return "update has been started"
